@@ -51,13 +51,14 @@ class pyproc2(object):
             self.data=[l.split(':',1) for l in self.raw.splitlines()]
             self.data=dict(self.data)
             self.data={k.lower().strip():v.lower().strip().replace('\t',' ') for k,v in self.data.items()}
+            self.name=self['name']
             #self.__dict__.update(self.data)
             self.uid=os.stat(self.path).st_uid
             try:
                 self.user=gpu(int(self.uid)).pw_name
             except KeyError:
                 self.user='root'
-                
+            self.owner=self.user   
             self.statusdata=open(os.path.join(self.path,'stat')).read().split()
             self.cmd=open(os.path.join(self.path,'cmdline')).read().strip().replace('\x00','')
             if 'state' not in self.data:
@@ -76,6 +77,7 @@ class pyproc2(object):
                     self.parent=pyproc2()._Process(self['ppid'],self.pid)
                 except ProcessLookupError:
                     pass
+            
         def __getitem__(self,i):
             return self.data[i]
         def __setitem__(self,n,i):
